@@ -9,26 +9,50 @@ class DisplayWebThing(Thing):
     # regarding capabilities refer https://iot.mozilla.org/schemas
     # there is also another schema registry http://iotschema.org/docs/full.html not used by webthing
 
-    def __init__(self, name: str, port_expander_name: str, address: int, num_lines: int, num_chars_per_line: int, description: str):
+    def __init__(self, name: str, description: str, lcd: Lcd):
         Thing.__init__(
             self,
-            'urn:dev:ops:display-1',
+            'urn:dev:ops:lcddisplay-1',
             (name + ' Display Controller').strip(),
             ['Display'],
             description
         )
 
-        self.display = Display(Lcd(port_expander_name, address, num_lines, num_chars_per_line), self.__update_text)
+        self.display = Display(lcd, self.__update_text)
 
-        self.text = Value("")
+        self.display_text = Value("")
         self.add_property(
             Property(self,
-                     'text',
-                     self.text,
+                     'displayed_text',
+                     self.display_text,
                      metadata={
-                         'title': 'text',
+                         'title': 'Displayed text',
                          'type': 'string',
-                         'description': 'The displayed text',
+                         'description': 'Displayed text',
+                         'readOnly': True,
+                     }))
+
+        self.num_rows = Value(lcd.num_lines)
+        self.add_property(
+            Property(self,
+                     'num_rows',
+                     self.num_rows,
+                     metadata={
+                         'title': 'Number of rows',
+                         'type': 'Integer',
+                         'description': 'Number of rows',
+                         'readOnly': True,
+                     }))
+
+        self.num_chars = Value(lcd.num_chars_per_line)
+        self.add_property(
+            Property(self,
+                     'num_chars',
+                     self.num_chars,
+                     metadata={
+                         'title': 'Number characters per row',
+                         'type': 'Integer',
+                         'description': 'Number characters per row',
                          'readOnly': True,
                      }))
 
@@ -111,18 +135,19 @@ class DisplayWebThing(Thing):
         self.ioloop.add_callback(self.__update_text_props)
 
     def __update_text_props(self):
-        self.text.notify_of_external_update(self.display.text)
-        self.upper_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_UPPER).text)
+        self.display_text.notify_of_external_update(self.display.text)
+        self.upper_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_UPPER).display_text)
         self.upper_layer_text_ttl.notify_of_external_update(self.display.panel(Display.LAYER_UPPER).ttl)
-        self.middle_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_MIDDLE).text)
+        self.middle_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_MIDDLE).display_text)
         self.middle_layer_text_ttl.notify_of_external_update(self.display.panel(Display.LAYER_MIDDLE).ttl)
-        self.lower_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_LOWER).text)
+        self.lower_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_LOWER).display_text)
         self.lower_layer_text_ttl.notify_of_external_update(self.display.panel(Display.LAYER_LOWER).ttl)
 
 
-def run_server(hostname: str, port: int, name:str, port_expander_name: str, address: int, num_lines: int, num_chars_per_line: int, description: str):
+def run_server(hostname: str, port: int, name:str, i2c_expander: str, i2c_address: int, num_lines: int, num_chars_per_line: int, description: str):
     logging.basicConfig(format='%(asctime)s %(levelname)-8s %(message)s', level=logging.INFO, datefmt='%Y-%m-%d %H:%M:%S')
-    display_webthing = DisplayWebThing(name,port_expander_name, address,  num_lines, num_chars_per_line, description)
+    lcd = Lcd.createI2C(i2c_expander, i2c_address)
+    display_webthing = DisplayWebThing(name, description, lcd)
     server = WebThingServer(SingleThing(display_webthing), hostname=hostname, port=port)
     try:
         logging.info('starting the server')
@@ -131,4 +156,3 @@ def run_server(hostname: str, port: int, name:str, port_expander_name: str, addr
         logging.info('stopping the server')
         server.stop()
         logging.info('done')
-
